@@ -34,6 +34,11 @@
 #include "gtksourcegutterrenderer.h"
 #include "gtksourcegutterrenderertext.h"
 #include "gtksourcegutterrendererpixbuf.h"
+#include "gtksourcehover.h"
+#include "gtksourcehovercontext.h"
+#include "gtksourcehoverdisplay.h"
+#include "gtksourcehoverprovider.h"
+#include "gtksourceindenter.h"
 #include "gtksourceinit.h"
 #include "gtksourcelanguage.h"
 #include "gtksourcelanguagemanager.h"
@@ -43,6 +48,7 @@
 #include "gtksourcemarkattributes.h"
 #include "gtksourceprintcompositor.h"
 #include "gtksourceregion.h"
+#include "gtksourcescheduler.h"
 #include "gtksourcesearchcontext.h"
 #include "gtksourcesearchsettings.h"
 #include "gtksourcesnippet.h"
@@ -56,10 +62,12 @@
 #include "gtksourcestyleschemechooserbutton.h"
 #include "gtksourcestyleschemechooserwidget.h"
 #include "gtksourcestyleschememanager.h"
+#include "gtksourcestyleschemepreview.h"
 #include "gtksourcetag.h"
 #include "gtksourceutils.h"
 #include "gtksourceversion.h"
 #include "gtksourceview.h"
+#include "gtksourcevimimcontext.h"
 #include "gtksource-enumtypes.h"
 
 #include "completion-providers/words/gtksourcecompletionwords.h"
