@@ -255,9 +255,15 @@ elements_end_element (GMarkupParseContext  *context,
 
 			for (guint i = 0; state->languages[i]; i++)
 			{
-				info.language = _gtk_source_snippet_manager_intern (state->manager, state->languages[i]);
+				char *stripped = g_strstrip (g_strdup (state->languages[i]));
 
-				gtk_source_snippet_bundle_add (state->self, &info);
+				if (stripped != NULL && stripped[0] != 0)
+				{
+					info.language = _gtk_source_snippet_manager_intern (state->manager, stripped);
+					gtk_source_snippet_bundle_add (state->self, &info);
+				}
+
+				g_free (stripped);
 			}
 
 		}
@@ -433,11 +439,17 @@ gtk_source_snippet_bundle_parse (GtkSourceSnippetBundle  *self,
 	gchar *contents = NULL;
 	gsize length = 0;
 	gboolean ret = FALSE;
+	GFile *file;
 
 	g_assert (GTK_SOURCE_IS_SNIPPET_BUNDLE (self));
 	g_assert (path != NULL);
 
-	if (g_file_get_contents (path, &contents, &length, NULL))
+	if (g_str_has_prefix (path, "resource://"))
+		file = g_file_new_for_uri (path);
+	else
+		file = g_file_new_for_path (path);
+
+	if (g_file_load_contents (file, NULL, &contents, &length, NULL, NULL))
 	{
 		GMarkupParseContext *context;
 		ParseState state = {0};
@@ -476,6 +488,8 @@ gtk_source_snippet_bundle_parse (GtkSourceSnippetBundle  *self,
 #endif
 	}
 
+	g_object_unref (file);
+
 	return ret;
 }
 
@@ -519,9 +533,9 @@ _gtk_source_snippet_bundle_merge (GtkSourceSnippetBundle *self,
 		return;
 	}
 
-	for (guint i = 0; i < other->infos->len; i++)
+	for (guint i = 0; i < self->infos->len; i++)
 	{
-		const GtkSourceSnippetInfo *info = &g_array_index (other->infos, GtkSourceSnippetInfo, i);
+		const GtkSourceSnippetInfo *info = &g_array_index (self->infos, GtkSourceSnippetInfo, i);
 		max_id = MAX (max_id, info->identifier);
 	}
 
@@ -625,6 +639,16 @@ create_snippet_from_info (GtkSourceSnippetBundle     *self,
 	return g_steal_pointer (&snippet);
 }
 
+GtkSourceSnippet *
+_gtk_source_snippet_bundle_create_snippet (GtkSourceSnippetBundle     *self,
+                                           const GtkSourceSnippetInfo *info)
+{
+	g_return_val_if_fail (GTK_SOURCE_IS_SNIPPET_BUNDLE (self), NULL);
+	g_return_val_if_fail (info != NULL, NULL);
+
+	return create_snippet_from_info (self, info);
+}
+
 static gboolean
 info_matches (const GtkSourceSnippetInfo *info,
               const gchar                *group,
@@ -701,7 +725,7 @@ _gtk_source_snippet_bundle_list_matching (GtkSourceSnippetBundle *self,
                                           const gchar            *trigger_prefix)
 {
 	GtkSourceSnippetBundle *ret;
-	const gchar *last = NULL;
+	const char *last = NULL;
 
 	g_return_val_if_fail (GTK_SOURCE_IS_SNIPPET_BUNDLE (self), NULL);
 
@@ -721,6 +745,15 @@ _gtk_source_snippet_bundle_list_matching (GtkSourceSnippetBundle *self,
 		}
 	}
 
+	g_array_set_size (ret->tooltips, self->tooltips->len);
+
+	if (self->tooltips->len > 0)
+	{
+		memcpy (ret->tooltips->data,
+			self->tooltips->data,
+			sizeof (GtkSourceSnippetTooltip) * self->tooltips->len);
+	}
+
 	return G_LIST_MODEL (g_steal_pointer (&ret));
 }
 
@@ -736,6 +769,18 @@ gtk_source_snippet_bundle_get_n_items (GListModel *model)
 	return GTK_SOURCE_SNIPPET_BUNDLE (model)->infos->len;
 }
 
+GtkSourceSnippetInfo *
+_gtk_source_snippet_bundle_get_info (GtkSourceSnippetBundle *self,
+                                     guint                   position)
+{
+	if (position >= self->infos->len)
+	{
+		return NULL;
+	}
+
+	return &g_array_index (self->infos, GtkSourceSnippetInfo, position);
+}
+
 static gpointer
 gtk_source_snippet_bundle_get_item (GListModel *model,
                                     guint       position)
