@@ -59,6 +59,7 @@
 #include <glib/gi18n-lib.h>
 #include <pango/pango.h>
 
+#include "gtksourcetrace.h"
 #include "gtksourceutils.h"
 #include "gtksourceutils-private.h"
 
@@ -73,7 +74,7 @@
 # endif
 #endif
 
-#ifdef ENABLE_FONT_CONFIG
+#if ENABLE_FONT_CONFIG
 # include <fontconfig/fontconfig.h>
 # include <pango/pangocairo.h>
 # include <pango/pangofc-fontmap.h>
@@ -967,7 +968,7 @@ _gtk_source_utils_aligned_free (gpointer data)
 	aligned_free (data);
 }
 
-#ifdef ENABLE_FONT_CONFIG
+#if ENABLE_FONT_CONFIG
 static PangoFontMap *
 load_override_font_fc (void)
 {
@@ -978,23 +979,27 @@ load_override_font_fc (void)
 
 	if (!font_map)
 	{
-		g_error ("Unable to create new fontmap");
+		g_warning ("Unable to create new fontmap");
 		return NULL;
 	}
 
 	if (g_once_init_enter (&map_font_config))
 	{
 		char **font_dirs = _gtk_source_utils_get_default_dirs ("fonts");
-		FcConfig *config = FcInitLoadConfigAndFonts ();
+		FcConfig *config = FcConfigCreate ();
 
 		if (font_dirs != NULL)
 		{
-			for (guint i = 0; font_dirs[i]; i++)
+			gboolean found = FALSE;
+
+			for (guint i = 0; !found && font_dirs[i]; i++)
 			{
 				char *font_path = g_build_filename (font_dirs[i], "BuilderBlocks.ttf", NULL);
 
 				if (g_file_test (font_path, G_FILE_TEST_IS_REGULAR))
 				{
+					found = TRUE;
+
 #ifdef G_OS_WIN32
 					/* Reformat the path as expected by win32 FontConfig */
 					FcChar8 *win32_path = FcStrCopyFilename ((const FcChar8 *)font_path);
@@ -1072,12 +1077,11 @@ PangoFontMap *
 _gtk_source_utils_get_builder_blocks (void)
 {
 	static PangoFontMap *builder_blocks_font_map;
-	static gboolean loaded;
+	static gsize loaded;
 
-	if (!loaded)
+	if (g_once_init_enter (&loaded))
 	{
-		loaded = TRUE;
-
+		GTK_SOURCE_PROFILER_BEGIN_MARK
 #ifdef FONTLOADING_WITH_PANGOWIN32
 		if (builder_blocks_font_map == NULL)
 		{
@@ -1091,6 +1095,9 @@ _gtk_source_utils_get_builder_blocks (void)
 			builder_blocks_font_map = load_override_font_fc ();
 		}
 #endif
+		GTK_SOURCE_PROFILER_END_MARK ("Fonts", "Loading BuilderBlocks font...");
+
+		g_once_init_leave (&loaded, TRUE);
 	}
 
 	return builder_blocks_font_map;
